@@ -1,15 +1,22 @@
 #!/bin/bash
 # Check if [acm]time values are copied from ext4 with full precision
 
-source "$TEST_TOP/common"
-source "$TEST_TOP/common.convert"
+source "$TEST_TOP/common" || exit
+source "$TEST_TOP/common.convert" || exit
 
-setup_root_helper
-prepare_test_dev
 check_prereq btrfs-convert
 check_global_prereq mke2fs
 
+setup_root_helper
+prepare_test_dev
+
 convert_test_prep_fs ext4 mke2fs -t ext4 -b 4096
+
+features=$(run_check_stdout dumpe2fs "$TEST_DEV" | grep "Filesystem features")
+if ! echo "$features" | grep -q "extra_isize"; then
+	_not_run "extended inode size not supported, no 64bit timestamp check possible"
+fi
+
 run_check $SUDO_HELPER touch "$TEST_MNT/file"
 # Read time values
 run_check stat "$TEST_MNT/file"
